@@ -469,12 +469,15 @@ timssParamForm <- function(itemParamDf, itemInfoDf, transConst, theYear, theLeve
   params$TIMSSid <- tolower(params$TIMSSid)
   colsNum <- c("a", "b", "c", "d1", "d2")
   params[colsNum] <- sapply(params[colsNum], as.numeric)
-  params$content_subtest <- ifelse(params$content_subtest == "Data Display", "mdat", params$content_subtest)
-  params$content_subtest <- ifelse(params$content_subtest == "Geometric Shapes and Measures", "mgeo", params$content_subtest)
+  params$content_subtest <- ifelse(params$content_subtest %in% c("Data Display","Data","Data and Probability","Data and Chance"), "mdat", params$content_subtest)
+  params$content_subtest <- ifelse(params$content_subtest %in% c("Geometric Shapes and Measures","Measurement and Geometry","Geometry"), "mgeo", params$content_subtest)
   params$content_subtest <- ifelse(params$content_subtest == "Number", "mnum", params$content_subtest)
+  params$content_subtest <- ifelse(params$content_subtest == "Algebra", "malg", params$content_subtest)
   params$content_subtest <- ifelse(params$content_subtest == "Earth Science", "sear", params$content_subtest)
   params$content_subtest <- ifelse(params$content_subtest == "Life Science", "slif", params$content_subtest)
-  params$content_subtest <- ifelse(params$content_subtest == "Physical Science", "sphy", params$content_subtest)
+  params$content_subtest <- ifelse(params$content_subtest == "Biology", "sbio", params$content_subtest)
+  params$content_subtest <- ifelse(params$content_subtest == "Chemistry", "sche", params$content_subtest)
+  params$content_subtest <- ifelse(params$content_subtest %in% c("Physical Science","Physics"), "sphy", params$content_subtest)
   prefix <- ifelse(subjectFilter == "MAT", "m", "s")
   params$cognitive_subtest <- ifelse(params$cognitive_subtest == "Applying", paste0(prefix, "app"), params$cognitive_subtest)
   params$cognitive_subtest <- ifelse(params$cognitive_subtest == "Knowing", paste0(prefix, "kno"), params$cognitive_subtest)
