@@ -1,3 +1,4 @@
+\dontrun{
 # read in the example data (generated, not real student data)
 sdf <- readNAEP(system.file("extdata/data", "M36NT2PM.dat", package = "NAEPprimer"))
 
@@ -6,3 +7,4 @@ isWeight(var="origwt", data=sdf)
 
 # FALSE
 isWeight(var="dsex", data=sdf)
+}
