@@ -5,14 +5,6 @@ options(width = 500)
 options(useFancyQuotes = FALSE)
 source("REF-9-YAFS.R") # has REF output in it
 
-if (!exists("edsurveyHome")) {
-  if (Sys.info()[["sysname"]] == "Windows") {
-    edsurveyHome <- "C:/EdSurveyData/"
-  } else {
-    edsurveyHome <- "~/EdSurveyData/"
-  }
-}
-
 if (!dir.exists(edsurveyHome)) {
   dir.create(edsurveyHome)
 }
@@ -43,7 +35,7 @@ test_that("PISA YAFS edsurveyTable", {
   lit <- edsurveyTable(
     formula = lit ~ 1,
     data = pisa_yafs,
-    omittedLevels = TRUE,
+    dropOmittedLevels = TRUE,
     jrrIMax = Inf
   )
   withr::with_options(list(digits = 7), out <- capture.output(lit))
